@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef NOTE_DISPLAY_ATTRIBUTE_H
-#define NOTE_DISPLAY_ATTRIBUTE_H
+#pragma once
 
 #include "noteshared_export.h"
 #include <AkonadiCore/Attribute>
@@ -84,4 +83,3 @@ private:
     bool mKeepBelow;
 };
 }
-#endif
