@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef NOTENETWORKCONFIG_H
-#define NOTENETWORKCONFIG_H
+#pragma once
 #include "noteshared_export.h"
 #include <KCModule>
 namespace NoteShared
@@ -28,11 +27,10 @@ class NOTESHARED_EXPORT NoteNetworkConfig : public KCModule
 {
     Q_OBJECT
 public:
-    explicit NoteNetworkConfig(QWidget *parent);
+    explicit NoteNetworkConfig(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
     /** Reimplemented from KCModule. */
     void load() override;
     void save() override;
 };
 }
 
-#endif // NOTENETWORKCONFIG_H
